import pytest
from sortuj_wedlug_rozmiaru_czesci_wspolnych import find_longest_common_substring, find_most_similar_line, sort_by_similarity

def test_find_longest_common_substring():
    assert find_longest_common_substring("hello world", "world peace") == (5, "world")
    assert find_longest_common_substring("abc", "def") == (0, "")
    assert find_longest_common_substring("test", "test") == (4, "test")

def test_find_most_similar_line():
    lines = ["hello world", "world peace", "peaceful day"]
    assert find_most_similar_line("hello world", lines) == (0, "hello world")
    assert find_most_similar_line("world", lines) == (0, "hello world")
    
    with pytest.raises(ValueError):
        find_most_similar_line("test", [])

def test_sort_by_similarity():
    lines = ["hello world", "world peace", "peaceful day"]
    sorted_lines = sort_by_similarity(lines)
    assert len(sorted_lines) == len(lines)
    assert sorted_lines[0] == "hello world"
    
    assert sort_by_similarity([]) == []
    assert sort_by_similarity(["single"]) == ["single"]

def test_sort_by_similarity_marked():
    lines = ["hello world", "world peace"]
    sorted_lines = sort_by_similarity(lines, marked=True)
    assert "[world]" in sorted_lines[1]

def test_sort_by_similarity_verbose(capsys):
    lines = ["hello world", "world peace"]
    sort_by_similarity(lines, verbose=True)
    captured = capsys.readouterr()
    assert "hello world" in captured.out
    assert "world peace" in captured.out
