import sys

'''
Wiesz, co to jest normalne sortowanie alfabetyczne? A wiesz, co to sortowanie a tergo? No to ja chcę mieć ich połączenie. Czyli dla każdej linijki pliku tekstowego:
* brać tę linijkę
* zmieniać ją na listę liczb (każda liczba to numer litery w alfabecie, nielitery pomijam)
* sumujemy element do elementu tę listę i reverse tej listy
* tak otrzymana lista liczb jest kluczem naszego sortowania
Napisz mi w Pythonie program, który to robi. Z linii poleceń niech dostaje nazwę pliku tekstowego

Oto alfabet - w moim pliku występują tylko te litery (oraz białe znaki, które ignorujemy): (...)
'''

def get_alphabet_map():
    alphabet = """A
À
Ą
B
C
Ć
D
E
É
Ę
F
G
H
I
J
K
L
Ł
M
N
Ń
O
Ó
P
Q
R
S
Ś
T
U
V
W
X
Y
Z
Ż
Ź""".splitlines()
    return {letter: idx + 1 for idx, letter in enumerate(alphabet)}

def line_to_numbers(line, alphabet_map):
    # Konwertuj linię na listę numerów (pozycji w alfabecie)
    return [alphabet_map[char] for char in line.upper() if char in alphabet_map]

def get_sort_key(line, alphabet_map):
    numbers = line_to_numbers(line, alphabet_map)
    if not numbers:  # Jeśli linia nie zawiera żadnych liter
        return [0]
    
    # Tworzymy listę oryginalną i odwróconą
    reversed_numbers = numbers[::-1]
    
    # Sumujemy element po elemencie
    combined = [a + b for a, b in zip(numbers, reversed_numbers)]
    return combined

def main():
    if len(sys.argv) != 2:
        print("Użycie: python script.py nazwa_pliku.txt")
        sys.exit(1)
    
    filename = sys.argv[1]
    alphabet_map = get_alphabet_map()
    
    try:
        with open(filename, 'r', encoding='utf-8') as file:
            lines = file.readlines()
        
        # Sortujemy linie używając naszej funkcji klucza
        sorted_lines = sorted(lines, key=lambda x: get_sort_key(x.strip(), alphabet_map))
        
        # Wypisujemy posortowane linie
        for line in sorted_lines:
            print(line.strip())
            
    except FileNotFoundError:
        print(f"Błąd: Plik {filename} nie został znaleziony.")
    except Exception as e:
        print(f"Wystąpił błąd: {e}")

if __name__ == "__main__":
    main()
