import sys

'''
Wiesz, co to jest normalne sortowanie alfabetyczne? A wiesz, co to sortowanie a tergo? No to ja chcę mieć ich połączenie. Czyli dla każdej linijki pliku tekstowego:
* brać tę linijkę
* zmieniać ją na listę liter (białe znaki pomijam)
* odwrócić tę listę (reverse)
* zrobić napis będący przeplotem tych dwu list - pierwsz znak z lewej, pierwszy z prawej, drugi znak z lewej, drugi z prawej...
* tak otrzymana lista liczb jest kluczem naszego sortowania
Napisz mi w Pythonie program, który to robi. Z linii poleceń niech dostaje nazwę pliku tekstowego
'''

def create_interleaved_key(line):
    # Usuń białe znaki i zamień na listę znaków
    chars = [c for c in line.strip() if not c.isspace()]
    
    # Stwórz listę normalną i odwróconą
    forward = chars
    backward = chars[::-1]
    
    # Stwórz przeplatany klucz
    interleaved = []
    for f, b in zip(forward, backward):
        interleaved.extend([f, b])
    
    # Jeśli długość jest nieparzysta, dodaj ostatni znak
    if len(chars) % 2 == 1:
        middle_index = len(chars) // 2
        interleaved.append(chars[middle_index])
    
    return ''.join(interleaved)

def sort_file(filename):
    try:
        # Wczytaj linie z pliku
        with open(filename, 'r', encoding='utf-8') as file:
            lines = file.readlines()
        
        # Posortuj linie używając klucza przeplatającego
        sorted_lines = sorted(lines, key=create_interleaved_key)
        
        # Wypisz posortowane linie
        for line in sorted_lines:
            print(line.rstrip())
            
    except FileNotFoundError:
        print(f"Błąd: Plik '{filename}' nie istnieje.")
        sys.exit(1)
    except Exception as e:
        print(f"Błąd podczas przetwarzania pliku: {e}")
        sys.exit(1)

if __name__ == "__main__":
    if len(sys.argv) != 2:
        print("Użycie: python program.py nazwa_pliku")
        sys.exit(1)
    
    sort_file(sys.argv[1])
