import pytest
from sortuj_z_obu_stron import (
    get_common_prefix_length,
    get_common_suffix_length,
    similarity_score,
    mark_common_parts,
    find_most_similar,
    sort_by_similarity
)

def test_get_common_prefix_length():
    assert get_common_prefix_length("", "") == 0
    assert get_common_prefix_length("abc", "abd") == 2
    assert get_common_prefix_length("abc", "abc") == 3
    assert get_common_prefix_length("short", "shorter") == 5
    assert get_common_prefix_length("xyz", "abc") == 0

def test_get_common_suffix_length():
    assert get_common_suffix_length("", "") == 0
    assert get_common_suffix_length("abc", "xbc") == 2
    assert get_common_suffix_length("abc", "abc") == 3
    assert get_common_suffix_length("testing", "running") == 3
    assert get_common_suffix_length("xyz", "abc") == 0

def test_similarity_score():
    assert similarity_score("abc", "abc") == 6  # 3 prefix + 3 suffix
    assert similarity_score("abcd", "abcx") == 3  # 3 prefix + 0 suffix
    assert similarity_score("xabc", "yabc") == 3  # 0 prefix + 3 suffix
    assert similarity_score("xyz", "abc") == 0  # 0 prefix + 0 suffix

def test_mark_common_parts():
    # Test prefix only
    assert mark_common_parts("abcdef", "abcxyz") == "[abc]def"
    # Test suffix only
    assert mark_common_parts("xyzdef", "abcdef") == "xyz[def]"
    # Test both prefix and suffix
    assert mark_common_parts("abcdefghi", "abcxyzghi") == "[abc]def[ghi]"
    # Test short common parts (should not be marked)
    assert mark_common_parts("abx", "aby") == "abx"

def test_find_most_similar():
    candidates = ["abcdef", "abcxyz", "xyzdef"]
    assert find_most_similar("abcdef", candidates) == "abcdef"
    assert find_most_similar("abcxxx", candidates) == "abcxyz"

def test_sort_by_similarity():
    input_lines = ["abcdef", "abcxyz", "xyzdef"]
    expected = ["abcdef", "abcxyz", "xyzdef"]
    assert sort_by_similarity(input_lines) == expected

def test_sort_by_similarity_with_marking():
    input_lines = ["abcdef", "abcxyz", "xyzdef"]
    expected = ["abcdef", "[abc]xyz", "xyz[def]"]
    assert sort_by_similarity(input_lines, marked=True) == expected

def test_empty_input():
    assert sort_by_similarity([]) == []

def test_single_line():
    assert sort_by_similarity(["abc"]) == ["abc"]
