import re
import html

def normalize_filename(title):
    title = title.lower()
    title = title.replace('ę', 'e')
    title = title.replace('ó', 'o')
    title = title.replace('ą', 'a')
    title = title.replace(' ', '_')
    return title

def custom_unescape(text):
    # Znane encje niestandardowe
    replacements = {
        '&ellipsis;': '…',    # U+2026 HORIZONTAL ELLIPSIS
        '&lguillemet;': '«',   # U+00AB LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
        '&lquote;': '„',       # U+201E DOUBLE LOW-9 QUOTATION MARK
        '&rguillemet;': '»',   # U+00BB RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
        '&rquote;': '"'        # U+201D RIGHT DOUBLE QUOTATION MARK
    }
    
    # Znajdź wszystkie encje w tekście
    import re
    entities = re.findall('&[a-zA-Z]+;', text)
    
    # Sprawdź, czy wszystkie encje są znane
    for entity in entities:
        if entity not in replacements and html.unescape(entity) == entity:
            raise ValueError(f"Napotkano nieznaną encję: {entity}")
    
    # Jeśli dotarliśmy tutaj, wszystkie encje są znane
    for entity, char in replacements.items():
        text = text.replace(entity, char)
    
    return html.unescape(text)

def validate_verse(verse):
    # Remove allowed tags
    cleaned = re.sub(r'<str/>\* \* \*', '', verse)
    cleaned = re.sub(r'</?i>|</?emph>|<str/>', '', cleaned)
    
    # Check for any remaining XML tags
    if re.search(r'<[^>]+>', cleaned):
        raise ValueError(f"Nieprawidłowy znacznik XML w tekście: {verse}")
    
    return cleaned

def process_pan_tadeusz(input_file):
    with open(input_file, 'r', encoding='utf-8') as f:
        content = f.read()
    
    books = re.split(r'<ksiega>', content)
   
    numer_ksiegi = 1
    for book in books[1:]:  # Skip the first empty element
        book_number = re.search(r'<numer>(.*?)</numer>', book)
        if not book_number:
            continue
            
        filename = normalize_filename(book_number.group(1))
        
        #verses = re.findall(r'<w>(.*?)</w>', book)
        verses = re.findall(r'<(?:w|rzecz)>(.*?)</(?:w|rzecz)>', book)
        
        with open(f"{numer_ksiegi:02}-{filename}.txt", 'w', encoding='utf-8') as f:
            for verse in verses:
                cleaned_verse = validate_verse(custom_unescape(verse))
                f.write(custom_unescape(cleaned_verse) + '\n')
        numer_ksiegi += 1

process_pan_tadeusz('pan-tadeusz.xml')

